@@ -1,5 +1,5 @@
 /********************************************************************************
- * Copyright (C) 2011-2014 by Stephen Allewell                                  *
+ * Copyright (C) 2011-2015 by Stephen Allewell                                  *
  * steve.allewell@gmail.com                                                     *
  *                                                                              *
  * This program is free software; you can redistribute it and/or modify         *
@@ -33,7 +33,7 @@
 #include <QPainterPath>
 #include <QMimeData>
 
-#include <KLocale>
+#include <KLocalizedString>
 
 #include "Editor.h"
 #include "SymbolLibrary.h"
